@@ -19,7 +19,7 @@ def clone_tree(args, data, ctx):
 
     # Get the template source directory (from command line)
     # It's the folder containing another folder named "template"
-    source_path = args["template"]
+    source_path = args["template_dir"]
     source_path = os.path.join(source_path, "template")
     source_path = os.path.abspath(source_path)
 
