@@ -3,7 +3,7 @@ import os
 from ..constants import TEMPLATE_NAME
 
 
-def exact_match(path):
+def find(path):
     """
     Search given path, then path/file.yml
     """
